@@ -33,7 +33,14 @@ extern "C" {
 #include <time.h>
 #include <stdarg.h>
 
-#include "gmime-part.h"
+typedef enum {
+        GMIME_PART_ENCODING_DEFAULT,
+        GMIME_PART_ENCODING_7BIT,
+        GMIME_PART_ENCODING_8BIT,
+        GMIME_PART_ENCODING_BASE64,
+        GMIME_PART_ENCODING_QUOTEDPRINTABLE,
+        GMIME_PART_NUM_ENCODINGS
+} GMimePartEncodingType;
 
 #define BASE64_ENCODE_LEN(x) ((guint) ((x) * 5 / 3) + 4)  /* conservative would be ((x * 4 / 3) + 4) */
 #define QP_ENCODE_LEN(x)     ((guint) ((x) * 7 / 2) + 4)  /* conservative would be ((x * 3) + 4) */
@@ -48,8 +55,8 @@ gchar *g_mime_utils_quote_string (const gchar *string);
 void   g_mime_utils_unquote_string (gchar *string);
 
 /* encoding decision making utilities ;-) */
-gboolean g_mime_utils_text_is_8bit (const guchar *text);
-GMimePartEncodingType g_mime_utils_best_encoding (const guchar *text);
+gboolean g_mime_utils_text_is_8bit (const guchar *text, guint len);
+GMimePartEncodingType g_mime_utils_best_encoding (const guchar *text, guint len);
 
 /* utilities to (de/en)code headers */
 gchar *g_mime_utils_8bit_header_decode (const guchar *in);
@@ -57,12 +64,14 @@ gchar *g_mime_utils_8bit_header_encode (const guchar *in);
 gchar *g_mime_utils_8bit_header_encode_phrase (const guchar *in);
 
 /* do incremental base64 (de/en)coding */
-gint g_mime_utils_base64_decode_step (const guchar *in, gint inlen, guchar *out, gint *state, guint *save);
-gint g_mime_utils_base64_encode_step (const guchar *in, gint inlen, guchar *out, gint *state, gint *save);
-gint g_mime_utils_base64_encode_close (const guchar *in, gint inlen, guchar *out, gint *state, gint *save);
+gint g_mime_utils_base64_decode_step (const guchar *in, gint inlen, guchar *out, gint *state, guint32 *save);
+gint g_mime_utils_base64_encode_step (const guchar *in, gint inlen, guchar *out, gint *state, guint32 *save);
+gint g_mime_utils_base64_encode_close (const guchar *in, gint inlen, guchar *out, gint *state, guint32 *save);
 
-/* do incremental uudecoding */
+/* do incremental uu (de/en)coding */
 gint g_mime_utils_uudecode_step (const guchar *in, gint inlen, guchar *out, gint *state, guint32 *save, gchar *uulen);
+gint g_mime_utils_uuencode_step (const guchar *in, gint inlen, guchar *out, guchar *uubuf, gint *state, guint32 *save, gchar *uulen);
+gint g_mime_utils_uuencode_close (const guchar *in, gint inlen, guchar *out, guchar *uubuf, gint *state, guint32 *save, gchar *uulen);
 
 /* do incremental quoted-printable (de/en)coding */
 gint g_mime_utils_quoted_decode_step (const guchar *in, gint inlen, guchar *out, gint *savestate, gint *saved);
